DONATE! — PyBSDDB 6.0.0 documentation

### Navigation

- index
- previous |
- PyBSDDB 6.0.0 documentation »

# DONATE!

Work on this project is currently driven by my own interests, needs and spare time. If you appreciate this software or if you want to sponsor a currently not translated API feature, please consider donation to the project.

PyBSDDB/BSDDB3 needs your help.

You can donate using BitCoins. The destination address is 16avqyUK4vDqBdpUy365PPW44zNqVHLZSC.

Since donations thru BitCoin are not revocable, please be sure your are transfering to the right account (this document could have been modified for a third party). You can verify it in two diffent ways:

1. Reading this document in the project original website: http://www.jcea.es/programacion/pybsddb_doc/donate.html. Make sure you are seeing the right webpage.

2. Verifying the PGP digital signature of the following document:

       -----BEGIN PGP SIGNED MESSAGE-----
       Hash: SHA1

       The BitCoin address for donating to PyBSDDB/BSDDB3 project
       is "16avqyUK4vDqBdpUy365PPW44zNqVHLZSC".

       -----BEGIN PGP SIGNATURE-----
       Version: GnuPG v1.4.10 (GNU/Linux)

       iQCVAwUBUcOqLplgi5GaxT1NAQIJWQP+MNdszxcFnlJFMMs/RmDEX5J4WeasoajY
       jHuHII2wrDxhTcneKeBFNwogmgZReFMTVp/emJ/kjidgXrWXOCfsEEcE/EesJq/u
       0m6f7LRLufKOi6JwqnYnsKSSJ9ikhsKS9nyTzCBXUETEPhkQ/e3vYy103WefVnOd
       hxw5UNrUOtk=
       =2VGk
       -----END PGP SIGNATURE-----

   Doing something like `gpg --verify` and pasting this block, your should get something like:

       gpg: Signature made Fri 21 Jun 2013 03:19:42 AM CEST using RSA key ID 9AC53D4D
       gpg: Good signature from "Jesus Cea Avion <jcea@jcea.es>"

   My PGP key ID is “9AC53D4D”. My key fingerprint is:

       pub   1024R/9AC53D4D 1995-01-01
             Key fingerprint = F4 07 90 C2 58 86 8A 75  45 40 33 1C 72 4C E5 E1
       uid                  Jesus Cea Avion <jcea@jcea.es>

### Navigation

- index
- previous |
- PyBSDDB 6.0.0 documentation »